@@ -1,17 +1,19 @@
 package BalanceOfPower::Commands;
-$BalanceOfPower::Commands::VERSION = '0.115000';
+$BalanceOfPower::Commands::VERSION = '0.120000';
 use v5.10;
 use Moo;
 use IO::Prompter;
 use Term::ANSIColor;
 use BalanceOfPower::Constants ":all";
-use BalanceOfPower::Utils qw(next_turn get_year_turns compare_turns evidence_text);
+use BalanceOfPower::Utils qw(next_turn prev_turn get_year_turns compare_turns evidence_text);
 use BalanceOfPower::Commands::Plain;
 use BalanceOfPower::Commands::NoArgs;
 use BalanceOfPower::Commands::InMilitaryRange;
-use BalanceOfPower::Commands::TargetRoute;
+use BalanceOfPower::Commands::DeleteRoute;
 use BalanceOfPower::Commands::MilitarySupport;
 use BalanceOfPower::Commands::RecallMilitarySupport;
+use BalanceOfPower::Commands::ComTreaty;
+use BalanceOfPower::Commands::NagTreaty;
 
 with 'BalanceOfPower::Role::Logger';
 
@@ -68,8 +70,9 @@ sub init
                                                         crisis_needed => 1 );
     push @{$self->commands}, $command; 
     $command =
-        BalanceOfPower::Commands::TargetRoute->new( name => "DELETE TRADEROUTE",
-                                                 world => $self->world );
+        BalanceOfPower::Commands::DeleteRoute->new( name => "DELETE TRADEROUTE",
+                                                    synonyms => ["DELETE ROUTE"],
+                                                    world => $self->world );
     push @{$self->commands}, $command; 
     $command =
         BalanceOfPower::Commands::NoArgs->new( name => "BOOST PRODUCTION",
@@ -88,13 +91,29 @@ sub init
                                                       world => $self->world,
                                                       allowed_at_war => 1,
                                                     );
+    push @{$self->commands}, $command; 
     $command =
         BalanceOfPower::Commands::InMilitaryRange->new( name => "AID INSURGENTS IN",
                                                              synonyms => ["AID INSURGENTS", "AID INSURGENCE"],
                                                              world => $self->world,
                                                              export_cost => AID_INSURGENTS_COST );
     push @{$self->commands}, $command; 
+    $command =
+        BalanceOfPower::Commands::ComTreaty->new( name => "COM TREATY WITH",
+                                                             synonyms => ["COM TREATY"],
+                                                             world => $self->world,
+                                                             prestige_cost => TREATY_PRESTIGE_COST 
+                                                            );
     push @{$self->commands}, $command; 
+    $command =
+        BalanceOfPower::Commands::NagTreaty->new( name => "NAG TREATY WITH",
+                                                             synonyms => ["NAG TREATY"],
+                                                             world => $self->world,
+                                                             #prestige_cost => TREATY_PRESTIGE_COST 
+                                                            );
+    push @{$self->commands}, $command; 
+
+
 }
 
 sub print_orders
@@ -146,6 +165,19 @@ sub welcome_player
     print $self->world->print_nation_actual_situation($self->world->player_nation);
     print "\n";
 }
+sub get_prompt_text
+{
+    my $self = shift;
+    my $prompt_text = "[" . $self->world->player . ", leader of " . $self->world->player_nation . ". Turn is " . $self->world->current_year . "]\n";
+    my $nation  = $self->world->get_player_nation();
+    $prompt_text .= "Int:" . $nation->production_for_domestic . "    Exp:" . $nation->production_for_export . "    Prtg:" . $nation->prestige . "\n";
+    if($self->world->order)
+    {
+        $prompt_text .= "=== ORDER SELECTED: " . $self->world->order . "\n";
+    }
+    $prompt_text .= $self->nation ? "(" . $self->nation . ") ?" : "?";
+    return $prompt_text;
+}
 
 sub get_query
 {
@@ -153,15 +185,10 @@ sub get_query
     if($self->query)
     {
         $self->log("[Not interactive query] " . $self->query);
+        return;
     }
-    my $prompt_text = "[" . $self->world->player . ", leader of " . $self->world->player_nation . ". Turn is " . $self->world->current_year . "]\n";
-    if($self->world->order)
-    {
-        $prompt_text .= "=== ORDER SELECTED: " . $self->world->order . "\n";
-    }
-    $prompt_text .= $self->nation ? "(" . $self->nation . ") ?" : "?";
     print color("cyan");
-    my $input_query = prompt $prompt_text;
+    my $input_query = prompt $self->get_prompt_text();
     $input_query .= "";
     print color("reset");
     while ($input_query =~ m/\x08/g) {
@@ -283,9 +310,10 @@ COMMANDS
         print $self->world->print_allies();
         $result = { status => 1 };
     }
-    elsif($query eq "situation")
+    elsif($query =~ /^situation( (.*))?$/)
     {
-        say $self->world->print_turn_statistics($self->world->current_year);  
+        my $order = $2;
+        say $self->world->print_turn_statistics($self->world->current_year, $order);  
         $result = { status => 1 };
     }
     elsif($query eq "supports")
@@ -374,7 +402,7 @@ COMMANDS
             }
             else
             {
-                print $self->world->print_nation_events($self->nation);
+                print $self->world->print_nation_events($self->nation, prev_turn($self->world->current_year) );
                 $result = { status => 1 };
             }
         }
@@ -422,7 +450,7 @@ COMMANDS
         my $nation_query = $self->world->correct_nation_name($query);
         if($self->verify_nation($nation_query)) #it's a nation
         { 
-            print $self->world->print_nation_actual_situation($nation_query);
+            print $self->world->print_nation_actual_situation($nation_query, 1);
             $self->nation($nation_query);
             $result = { status => 1 };
         }
@@ -491,6 +519,7 @@ sub orders
 sub interact
 {
     my $self = shift;
+    $self->world->pre_decisions_elaborations();
     while($self->active)
     {
         my $result = undef;
@@ -499,8 +528,10 @@ sub interact
         $result = $self->turn_command();
         if($result->{status} == 1)
         {
-            $self->world->elaborate_turn();
+            say "Elaborating " . $self->world->current_year . "...\n";
+            $self->world->post_decisions_elaborations();
             say evidence_text($self->world->print_formatted_turn_events($self->world->current_year), $self->world->player_nation);
+            $self->world->pre_decisions_elaborations();
             next;
         }
         $result = $self->report_commands();
