@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands::Role::Command;
-$BalanceOfPower::Commands::Role::Command::VERSION = '0.115000';
+$BalanceOfPower::Commands::Role::Command::VERSION = '0.120000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -24,6 +24,10 @@ has domestic_cost => (
     is => 'ro',
     default => 0
 );
+has prestige_cost => (
+    is => 'ro',
+    default => 0
+);
 
 has allowed_at_war => (
     is => 'ro',
@@ -75,6 +79,10 @@ sub allowed
     {
         return 0;
     }
+    if($self->world->get_player_nation()->prestige < $self->prestige_cost)
+    {
+        return 0;
+    }
     return 1;
 }
 
