@@ -1,5 +1,5 @@
 package BalanceOfPower::Constants;
-$BalanceOfPower::Constants::VERSION = '0.115000';
+$BalanceOfPower::Constants::VERSION = '0.120000';
 use strict;
 
 use base 'Exporter';
@@ -71,7 +71,7 @@ use constant ALLIANCE_FRIENDSHIP_FACTOR => 200;
 use constant ALLY_CONFLICT_LEVEL_FOR_INVOLVEMENT => 2;
 use constant STARTING_ALLIANCES => 7;
 use constant EMERGENCY_PRODUCTION_LIMIT => 55;
-use constant BOOST_PRODUCTION_QUOTE => 15;
+use constant BOOST_PRODUCTION_QUOTE => 5;
 use constant MIN_ARMY_TO_EXPORT => 12;
 use constant ARMY_TO_ACCEPT_MILITARY_SUPPORT => 10;
 use constant ARMY_FOR_SUPPORT => 4;
@@ -88,6 +88,8 @@ use constant INFLUENCE_PRESTIGE_BONUS => 3;
 use constant BEST_WEALTH_FOR_PRESTIGE => 5;
 use constant BEST_WEALTH_FOR_PRESTIGE_BONUS => 5;
 use constant WAR_PRESTIGE_BONUS => 10;
+use constant TREATY_PRESTIGE_COST => 7;
+use constant TREATY_TRADE_FACTOR => .5;
 
 our @EXPORT_OK = ('MIN_EXPORT_QUOTE', 
                   'MAX_EXPORT_QUOTE',
@@ -172,6 +174,8 @@ our @EXPORT_OK = ('MIN_EXPORT_QUOTE',
                   'INFLUENCE_PRESTIGE_BONUS',
                   'BEST_WEALTH_FOR_PRESTIGE',
                   'BEST_WEALTH_FOR_PRESTIGE_BONUS',
-                  'WAR_PRESTIGE_BONUS'
+                  'WAR_PRESTIGE_BONUS',
+                  'TREATY_PRESTIGE_COST',
+                  'TREATY_TRADE_FACTOR'
                 );
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
