@@ -1,9 +1,11 @@
 package BalanceOfPower::Nation;
-$BalanceOfPower::Nation::VERSION = '0.115000';
+$BalanceOfPower::Nation::VERSION = '0.120000';
 use strict;
 use v5.10;
 
 use Moo;
+use Array::Utils qw(intersect);
+
 use BalanceOfPower::Utils qw( prev_turn );
 use BalanceOfPower::Constants ':all';
 
@@ -123,8 +125,19 @@ sub calculate_trading
         {
            if($self->production_for_export >= TRADING_QUOTE)
            {
-                $self->trade(TRADING_QUOTE, $r->factor_for_node($self->name));
-                $self->register_event("TRADE OK " . $r->destination($self->name) . " [x" . $r->factor_for_node($self->name) . "]");
+                my $treaty_bonus = 0;
+                if($world->exists_treaty_by_type($self->name, $r->destination($self->name), 'commercial'))
+                {
+                    $treaty_bonus = TREATY_TRADE_FACTOR;
+                }
+                $self->trade(TRADING_QUOTE, $r->factor_for_node($self->name) + $treaty_bonus);
+                my $event = "TRADE OK " . $r->destination($self->name) . " [x" . $r->factor_for_node($self->name);
+                if($treaty_bonus > 0)
+                {
+                    $event .= " +$treaty_bonus";
+                }
+                $event .= "]";
+                $self->register_event($event);
            }
            else
            {
@@ -151,8 +164,9 @@ sub war_cost
 sub boost_production
 {
     my $self = shift;
-    $self->subtract_production('export', -1 * BOOST_PRODUCTION_QUOTE);
-    $self->subtract_production('domestic', -1 * BOOST_PRODUCTION_QUOTE);
+    my $boost = BOOST_PRODUCTION_QUOTE * PRODUCTION_UNITS->[$self->size];
+    $self->subtract_production('export', -1 * $boost);
+    $self->subtract_production('domestic', -1 * $boost);
     $self->register_event("BOOST OF PRODUCTION");
 }
 
@@ -213,11 +227,11 @@ sub decision
         my $decision = undef;
         if($a eq 'domestic')
         {
-            $decision = $self->domestic_advisor();
+            $decision = $self->domestic_advisor($world);
         }
         elsif($a eq 'economy')
         {
-            $decision = $self->economy_advisor();
+            $decision = $self->economy_advisor($world);
         }
         elsif($a eq 'military')
         {
@@ -413,10 +427,12 @@ sub good_prey
 #
 # LOWER DISORDER
 # BOOST PRODUCTION
+# TREATY NAG
 
 sub domestic_advisor
 {
     my $self = shift;
+    my $world = shift;
     if($self->internal_disorder > WORRYING_LIMIT && $self->production_for_domestic > DOMESTIC_BUDGET)
     {
         return $self->name . ": LOWER DISORDER";
@@ -425,6 +441,104 @@ sub domestic_advisor
     {
         return $self->name . ": BOOST PRODUCTION";
     }
+    elsif($self->prestige >= TREATY_PRESTIGE_COST)
+    {
+        #Scanning neighbors
+        my @near = $world->near_nations($self->name, 1);
+        my @friends = $world->get_nations_with_status($self->name, ['NEUTRAL', 'FRIENDSHIP', 'ALLIANCE']);
+        my @friendly_neighbors = $world->shuffle("Mixing neighbors to choose about NAG treaty", intersect(@near, @friends));
+        my @ordered_friendly_neighbors = ();
+        my $dangerous_neighbor = 0;
+        for(@friendly_neighbors)
+        {
+            my $n = $_;
+            if(! $world->exists_treaty($self->name, $n))
+            {
+                my @supporter = $world->supported($n);
+                if(@supporter > 0)
+                {
+                    my $supporter_nation = $supporter[0]->node1;
+                    if($supporter_nation eq $self->name)
+                    {
+                        #I'm the supporter of this nation!
+                        push @ordered_friendly_neighbors, { nation => $n,
+                                                            interest => 0 };
+                    }
+                    else
+                    {
+                        if($world->crisis_exists($self->name, $supporter_nation))
+                        {
+                            push @ordered_friendly_neighbors, { nation => $n,
+                                                                interest => 100 };
+                            $dangerous_neighbor = 1;
+                        }
+                        elsif($world->diplomacy_status($self->name, $supporter_nation) eq 'HATE')
+                        {
+                            push @ordered_friendly_neighbors, { nation => $n,
+                                                            interest => 10 };
+                        }
+                        else
+                        {
+                            push @ordered_friendly_neighbors, { nation => $n,
+                                                                interest => 2 };
+                        }
+                    }
+                }
+                else
+                {
+                    push @ordered_friendly_neighbors, { nation => $n,
+                                                        interest => 1 };
+                }
+            }
+        }
+        if(@ordered_friendly_neighbors > 0 && $dangerous_neighbor)
+        {
+            @ordered_friendly_neighbors = sort { $b->{interest} <=> $a->{interest} } @ordered_friendly_neighbors;
+            return $self->name . ": TREATY NAG WITH " . $ordered_friendly_neighbors[0]->{nation};
+        }
+        else
+        {
+            #Scanning crises
+            my @crises = $world->get_crises($self->name);
+            if(@crises > 0)
+            {
+                foreach my $c ($world->shuffle("Mixing crisis for war for " . $self->name, @crises))
+                {
+                    #NAG with enemy supporter
+                    my $enemy = $c->destination($self->name);
+                    my @supporter = $world->supported($enemy);
+                    if(@supporter > 0)
+                    {
+                        my $supporter_nation = $supporter[0]->node1;
+                        if($supporter_nation ne $self->name &&
+                           $world->diplomacy_status($self->name, $supporter_nation) ne 'HATE' &&
+                           ! $world->exists_treaty($self->name, $supporter_nation))
+                        {
+                            return $self->name . ": TREATY NAG WITH " . $supporter_nation;
+                        } 
+                    }
+                    #NAG with enemy ally
+                    my @allies = $world->get_allies($enemy);
+                    for($world->shuffle("Mixing allies of enemy for a NAG", @allies))
+                    {
+                        my $all = $_->destination($enemy);
+                        if($all ne $self->name &&
+                           $world->diplomacy_status($self->name, $all) ne 'HATE' &&
+                           ! $world->exists_treaty($self->name, $all))
+                        {
+                            return $self->name . ": TREATY NAG WITH " . $all;
+                        } 
+                    }
+                }
+            }
+            if(@ordered_friendly_neighbors > 0)
+            {
+                @ordered_friendly_neighbors = sort { $b->{interest} <=> $a->{interest} } @ordered_friendly_neighbors;
+                return $self->name . ": TREATY NAG WITH " . $ordered_friendly_neighbors[0]->{nation};
+            }
+            return undef;
+        }
+    }
     else
     {
         return undef;
@@ -435,17 +549,43 @@ sub domestic_advisor
 #
 # DELETE TRADEROUTE
 # ADD ROUTE
+# TREATY COM
 
 sub economy_advisor
 {
     my $self = shift;
+    my $world = shift;
     my $prev_year = prev_turn($self->current_year);
+    my @trade_ok = $self->get_events("TRADE OK", $prev_year);
+    if($self->prestige >= TREATY_PRESTIGE_COST && @trade_ok > 0)
+    {
+        for(@trade_ok)
+        {
+            my $route = $_;
+            $route =~ s/^TRADE OK //;
+            $route =~ s/ \[.*$//;
+            my $status = $world->diplomacy_status($self->name, $route);
+            if(! $world->exists_treaty($self->name, $route) && $status ne 'HATE')
+            {
+                return $self->name . ": TREATY COM WITH " . $route;
+            }
+        }
+    }
     my @trade_ko = $self->get_events("TRADE KO", $prev_year);
     if(@trade_ko > 1)
     {
-        my $to_delete = $trade_ko[$#trade_ko];
-        $to_delete =~ s/TRADE KO //;
-        return $self->name . ": DELETE TRADEROUTE " . $self->name . "->" . $to_delete;
+        #my $to_delete = $trade_ko[$#trade_ko];
+        #$to_delete =~ s/TRADE KO //;
+        #return $self->name . ": DELETE TRADEROUTE " . $self->name . "->" . $to_delete;
+        for(@trade_ko)
+        {
+            my $to_delete = $_;
+            $to_delete =~ s/TRADE KO //;
+            if(! $world->exists_treaty_by_type($self->name, $to_delete, 'commercial'))
+            {
+                return $self->name . ": DELETE TRADEROUTE " . $self->name . "->" . $to_delete;   
+            }
+        }
     }
     elsif(@trade_ko == 1)
     {
@@ -454,7 +594,10 @@ sub economy_advisor
         {
             my $to_delete = $trade_ko[$#trade_ko];
             $to_delete =~ s/TRADE KO //;
-            return $self->name . ": DELETE TRADEROUTE " . $self->name . "->" . $to_delete;
+            if(! $world->exists_treaty_by_type($self->name, $to_delete, 'commercial'))
+            {
+                return $self->name . ": DELETE TRADEROUTE " . $self->name . "->" . $to_delete;
+            }
         }
     }
     else
@@ -622,7 +765,7 @@ sub new_government
     my $world = shift;
     $self->government_strength($world->random10(MIN_GOVERNMENT_STRENGTH, MAX_GOVERNMENT_STRENGTH, "Reroll government strength for " . $self->name));
     $world->reroll_diplomacy($self->name);
-    $world->reset_alliances($self->name);
+    $world->reset_treaties($self->name);
     $world->reset_influences($self->name);
     $world->reset_supports($self->name);
     $world->reset_crises($self->name);
@@ -632,7 +775,7 @@ sub occupation
 {
     my $self = shift;
     my $world = shift;
-    $world->reset_alliances($self->name);
+    $world->reset_treaties($self->name);
     $world->reset_influences($self->name);
     $world->reset_supports($self->name);
     $world->reset_crises($self->name);
