@@ -1,5 +1,5 @@
 package BalanceOfPower::Relations::RelPack;
-$BalanceOfPower::Relations::RelPack::VERSION = '0.115000';
+$BalanceOfPower::Relations::RelPack::VERSION = '0.120000';
 use strict;
 use v5.10;
 
@@ -24,6 +24,13 @@ sub all
     my $self = shift;
     return @{$self->links};
 }
+sub reset
+{
+    my $self = shift;
+    $self->links([]);
+    $self->links_grid({});
+    $self->distance_cache({});
+}
 
 sub exists_link
 {
