@@ -1,10 +1,10 @@
 package BalanceOfPower::Role::Analyst;
-$BalanceOfPower::Role::Analyst::VERSION = '0.115000';
+$BalanceOfPower::Role::Analyst::VERSION = '0.120000';
 use strict;
 use v5.10;
 use Moo::Role;
 use Term::ANSIColor;
-use BalanceOfPower::Utils qw( as_title as_subtitle );
+use BalanceOfPower::Utils qw( prev_turn as_title as_subtitle );
 
 requires 'diplomacy_exists';
 requires 'get_borders';
@@ -23,7 +23,16 @@ sub print_nation_actual_situation
 {
     my $self = shift;
     my $nation = shift;
-    my $turn = $self->current_year;
+    my $in_the_middle = shift;
+    my $turn = shift;
+    if($in_the_middle)
+    {
+        $turn = prev_turn($self->current_year);
+    }
+    else
+    {
+        $turn = $self->current_year;
+    }
     my $nation_obj = $self->get_nation($nation);
     my $out = as_title("$nation\n===\n");
     $out .= $nation_obj->print_attributes();
@@ -39,12 +48,12 @@ sub print_nation_actual_situation
         $out .= $tr->print($nation) . "\n";
     }
     $out .= "\n";
-    my $allies_support_title = sprintf "%-35s %-35s", "ALLIES", "SUPPORTS";
+    my $allies_support_title = sprintf "%-35s %-35s", "TREATIES", "SUPPORTS";
     $allies_support_title .="\n";
     $allies_support_title .= sprintf "%-35s %-35s", "---", "---";
     $allies_support_title .="\n";
     $out .= as_title($allies_support_title);
-    my @allies = $self->get_allies($nation);
+    my @allies = $self->get_treaties_for_nation($nation);
     my @supports = $self->supports($nation);
     for(my $i = 0; ;$i++)
     {
