@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Reporter;
-$BalanceOfPower::Role::Reporter::VERSION = '0.115000';
+$BalanceOfPower::Role::Reporter::VERSION = '0.120000';
 use strict;
 use v5.10;
 use Moo::Role;
@@ -61,7 +61,7 @@ sub print_turn_events
     }
     foreach my $t (@to_print)
     {
-        $out .= as_title("- $t\n");
+        $out .= as_title($self->name . " - $t\n");
         foreach my $e (@{$self->events->{$t}})
         {
             $out .= " " . $e . "\n";
