@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Warlord;
-$BalanceOfPower::Role::Warlord::VERSION = '0.115000';
+$BalanceOfPower::Role::Warlord::VERSION = '0.120000';
 use strict;
 use v5.10;
 
@@ -64,15 +64,20 @@ sub in_military_range
     my $self = shift;
     my $nation1 = shift;
     my $nation2 = shift;
+    my $hostile = shift || 1;
     return 1 if($self->border_exists($nation1, $nation2));
     my @supported = $self->supporter($nation1);
     for(@supported)
     {
         my $nation_supported = $_->destination($nation1);
-        if(! $self->war_busy($nation_supported))
+        my $treaty = $self->exists_treaty_by_type($nation_supported, $nation2, 'no aggression');
+        if(! $hostile || ! $treaty)
         {
-            return 1 if $nation_supported eq $nation2 ||
-                        $self->border_exists($nation_supported, $nation2);
+            if(! $self->war_busy($nation_supported))
+            {
+                return 1 if $nation_supported eq $nation2 ||
+                            $self->border_exists($nation_supported, $nation2);
+            }
         }
     }
     my @empire = $self->empire($nation1);
@@ -188,7 +193,7 @@ sub create_war
             }
             @potential_attackers = $self->shuffle("War creation. Choosing attackers", @potential_attackers);
             my $attack_now = $potential_attackers[0];
-            my $defend_now;
+            my $defend_now = undef;
             my $free_level = 0;
             my $searching = 1;
             while($searching)
@@ -196,12 +201,25 @@ sub create_war
                 my @potential_defenders;
                 if($faction == 0)
                 {
-                    @potential_defenders = grep { $used{$_} <= $free_level } @defender_coalition;
+                    @potential_defenders = grep { ! $self->exists_treaty_by_type($_, $attack_now, 'no aggression') } @defender_coalition;
+                    if(@potential_defenders == 0)
+                    {
+                        @attacker_coalition = grep { ! $attack_now eq $_ } @attacker_coalition;
+                        $self->broadcast_event("NO POSSIBILITY TO PARTECIPATE TO WAR LINKED TO WAR BETWEEN " . $attacker->name . " AND " .$defender->name . " FOR $attack_now", $attack_now);
+                        last;
+                    }
                 }
                 elsif($faction == 1)
                 {
-                    @potential_defenders = grep { $used{$_} <= $free_level } @attacker_coalition;
+                    @potential_defenders = grep { ! $self->exists_treaty_by_type($_, $attack_now, 'no aggression') } @attacker_coalition;
+                    if(@potential_defenders == 0)
+                    {
+                        @defender_coalition = grep { ! $attack_now eq $_ } @defender_coalition;
+                        $self->broadcast_event("NO POSSIBILITY TO PARTECIPATE TO WAR LINKED TO WAR BETWEEN " . $attacker->name . " AND " .$defender->name . " FOR $attack_now", $attack_now);
+                        last;
+                    }
                 }
+                @potential_defenders = grep { $used{$_} <= $free_level } @potential_defenders;
                 if(@potential_defenders > 0)
                 {
                     @potential_defenders = $self->shuffle("War creation. Choosing defenders", @potential_defenders);
@@ -213,10 +231,13 @@ sub create_war
                     $free_level++;
                 }
             }
-            push @war_couples, [$attack_now, $defend_now];
-            push @couples_factions, $faction;
+            if($defend_now)
+            {
+                push @war_couples, [$attack_now, $defend_now];
+                push @couples_factions, $faction;
+                $used{$defend_now} += 1;
+            }
             $used{$attack_now} += 1;
-            $used{$defend_now} += 1;
             if($faction == 0)
             {
                 $faction = 1;
@@ -290,7 +311,9 @@ sub damage_from_battle
     my $self = shift;
     my $nation = shift;
     my $damage = shift;
+    my $attacker = shift;
     my @supported = $self->supported($nation->name);
+    @supported = grep { ! $self->exists_treaty_by_type($attacker->name, $_->node1, 'no aggression') } @supported;
     my $flip = 0;
     my $army_damage = 0;
     while($damage > 0)
@@ -358,18 +381,24 @@ sub fight_wars
         for($self->supported($attacker->name))
         {
             my $supporter_n = $_->start($attacker->name);
-            $self->broadcast_event("RELATIONS BETWEEN " . $defender->name . " AND " . $supporter_n . " CHANGED FOR WAR WITH " . $attacker->name, $attacker->name, $defender->name, $supporter_n);
-            $self->change_diplomacy($defender->name, $supporter_n, -1 * DIPLOMACY_MALUS_FOR_SUPPORT);
+            if(! $self->exists_treaty_by_type($defender->name, $supporter_n, 'no aggression'))
+            {
+                $self->broadcast_event("RELATIONS BETWEEN " . $defender->name . " AND " . $supporter_n . " CHANGED FOR WAR WITH " . $attacker->name, $attacker->name, $defender->name, $supporter_n);
+                $self->change_diplomacy($defender->name, $supporter_n, -1 * DIPLOMACY_MALUS_FOR_SUPPORT);
+            }
         }
         for($self->supported($defender->name))
         {
             my $supporter_n = $_->start($defender->name);
-            $self->broadcast_event("RELATIONS BETWEEN " . $attacker->name . " AND " . $supporter_n . " CHANGED FOR WAR WITH " . $defender->name, $attacker->name, $defender->name, $supporter_n);
-            $self->change_diplomacy($attacker->name, $supporter_n, -1 * DIPLOMACY_MALUS_FOR_SUPPORT);
+            if(! $self->exists_treaty_by_type($attacker->name, $supporter_n, 'no aggression'))
+            {
+                $self->broadcast_event("RELATIONS BETWEEN " . $attacker->name . " AND " . $supporter_n . " CHANGED FOR WAR WITH " . $defender->name, $attacker->name, $defender->name, $supporter_n);
+                $self->change_diplomacy($attacker->name, $supporter_n, -1 * DIPLOMACY_MALUS_FOR_SUPPORT);
+            }
         }
 
-        $self->damage_from_battle($attacker, $attacker_damage);
-        $self->damage_from_battle($defender, $defender_damage);
+        $self->damage_from_battle($attacker, $attacker_damage, $defender);
+        $self->damage_from_battle($defender, $defender_damage, $attacker);
         $attacker->register_event("CASUALITIES IN WAR WITH " . $defender->name . ": $attacker_damage");
         $defender->register_event("CASUALITIES IN WAR WITH " . $attacker->name . ": $defender_damage");
         if($attacker->army == 0)
