@@ -1,5 +1,5 @@
 package BalanceOfPower::World;
-$BalanceOfPower::World::VERSION = '0.115000';
+$BalanceOfPower::World::VERSION = '0.120000';
 use strict;
 use v5.10;
 
@@ -17,6 +17,10 @@ has name => (
     is => 'ro',
     default => 'WORLD'
 );
+has silent => (
+    is => 'rw',
+    default => 0
+);
 has first_year => (
     is => 'ro'
 );
@@ -45,7 +49,6 @@ has data_directory => (
         my $module_file_path = __FILE__;
         my $root_path = abs_path($module_file_path);
         $root_path =~ s/World\.pm//;
-        say $root_path . "data"; 
         my $data_directory = $root_path . "data";
 
     }
@@ -180,58 +183,63 @@ sub init_random
     foreach my $n (keys %nations_data)
     {
         push @nation_names, $n;
-        say "Working on $n";
+        say "Working on $n" if ! $self->silent;
         my $export_quote = $self->random10(MIN_EXPORT_QUOTE, MAX_EXPORT_QUOTE, "Export quote $n");
-        say "  export quote: $export_quote";
+        say "  export quote: $export_quote" if ! $self->silent;
         my $government_strength = $self->random10(MIN_GOVERNMENT_STRENGTH, MAX_GOVERNMENT_STRENGTH, "Government strenght $n");
-        say "  government strength: $government_strength";
+        say "  government strength: $government_strength" if ! $self->silent;
         push @{$self->nations}, BalanceOfPower::Nation->new( 
             name => $n, 
             area => $nations_data{$n}->{area}, 
             size => $nations_data{$n}->{size},
             government => $nations_data{$n}->{government},
             export_quote => $export_quote, 
-            government_strength => $government_strength);
+            government_strength => $government_strength,
+            log_name => $self->log_name);
     }
     $self->nation_names(\@nation_names);
     $self->load_borders($bordersfile);
     if($trades)
     {
-        say "Trades generation...";
+        say "Trades generation..." if ! $self->silent;
         $self->init_trades();
     }
     else
     {
-        say "Trades generation skipped";
+        say "Trades generation skipped" if ! $self->silent;
     }
     if($diplomacy)
     {
-        say "Diplomacy generation...";
+        say "Diplomacy generation..." if ! $self->silent;
         $self->init_diplomacy();
     }
     else
     {
-        say "Diplomacy generation skipped";
+        say "Diplomacy generation skipped" if ! $self->silent;
     }
     if($alliances)
     {
-        say "Alliances generation...";
+        say "Alliances generation..." if ! $self->silent;
         $self->init_random_alliances();
     }
     else
     {
-        say "Alliances generation skipped";
+        say "Alliances generation skipped" if ! $self->silent;
     }
 }
 
 #Group function for all the steps involved in a turn
-sub elaborate_turn
+sub pre_decisions_elaborations
 {
     my $self = shift;
     my $t = shift;
     $self->init_year($t);
     $self->war_debts();
     $self->crisis_generator();
+}
+sub post_decisions_elaborations
+{
+    my $self = shift;
     $self->execute_decisions();
     $self->economy();
     $self->warfare();
@@ -240,6 +248,16 @@ sub elaborate_turn
     $self->collect_events();
 }
 
+
+
+sub elaborate_turn
+{
+    my $self = shift;
+    my $t = shift;
+    $self->pre_decisions_elaborations($t);
+    $self->post_decisions_elaborations();
+}
+
 #To automatically generate turns
 sub autopilot
 {
@@ -272,7 +290,7 @@ sub init_year
         $turn = next_turn($self->current_year);
     }
     $self->log("--- $turn ---");
-    say $turn;
+    say $turn if $self->autoplay();
     $self->current_year($turn);
     foreach my $n (@{$self->nations})
     {
@@ -401,13 +419,13 @@ sub calculate_prestige
     $prestige += @supported;
     my @influenced = $self->has_influence($nation_name);
     $prestige += @influenced * INFLUENCE_PRESTIGE_BONUS;
-    my @ordered_wealth = $self->order_statistics(prev_turn($nation->current_year), 'wealth');
+    my @ordered_best = $self->order_statistics(prev_turn($nation->current_year), 'w/d');
     my $bonus = 0;
-    if(@ordered_wealth >= BEST_WEALTH_FOR_PRESTIGE)
+    if(@ordered_best >= BEST_WEALTH_FOR_PRESTIGE)
     {
         for(my $i = 0; $i < BEST_WEALTH_FOR_PRESTIGE; $i++)
         {
-            if($ordered_wealth[$i]->{nation} eq $nation_name)
+            if($ordered_best[$i]->{nation} eq $nation_name)
             {
                 $bonus = BEST_WEALTH_FOR_PRESTIGE_BONUS;
                 $self->broadcast_event("ONE OF THE FIRST " . BEST_WEALTH_FOR_PRESTIGE . " NATIONS FOR WEALTH WAS " . $nation_name, $nation_name);
@@ -492,6 +510,12 @@ sub execute_decisions
             my $victim = $self->get_nation($2);
             $self->aid_insurgents($attacker, $victim);
         }
+        elsif($d =~ /^(.*): TREATY (.*) WITH (.*)$/)
+        {
+            my $nation1 = $self->get_nation($1);
+            my $nation2 = $self->get_nation($3);
+            $self->stipulate_treaty($nation1, $nation2, $2);
+        }
     }
     $self->manage_route_adding(@route_adders);
 }
@@ -587,7 +611,21 @@ sub economy
         {
             $n->war_cost();
         }
+
+        my $wealth = $n->wealth;
+        my $pu = PRODUCTION_UNITS->[$n->size];
+        my $prod = $self->get_statistics_value($self->current_year, $n->name, 'production');
+
         $self->set_statistics_value($n, 'wealth', $n->wealth);
+        $self->set_statistics_value($n, 'w/d', int(($wealth / $pu) * 100) / 100);
+        if($prod != 0)
+        {
+            $self->set_statistics_value($n, 'growth', int(($wealth / $prod) * 100) / 100 );
+        }
+        else
+        {
+            $self->set_statistics_value($n, 'growth', 'X' );
+        }
     }
 }
 
@@ -649,6 +687,63 @@ sub warfare
 }
 # WAR END ##################################################################
 
+# TREATIES #################################################################
+
+sub stipulate_treaty
+{
+    my $self = shift;
+    my $nation1 = shift;
+    my $nation2 = shift;
+    my $type = shift;
+    my $present_treaty = $self->exists_treaty($nation1->name, $nation2->name);
+    my $diplomatic_status = $self->diplomacy_status($nation1->name, $nation2->name);
+    if($diplomatic_status eq 'HATE')
+    {
+        $self->broadcast_event("TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name . " NOT POSSIBLE BECAUSE OF HATE", $nation1->name, $nation2->name);
+        return;
+    }
+    if($nation1->prestige >= TREATY_PRESTIGE_COST)
+    {
+        if($type eq 'COM')
+        {
+            if(! $present_treaty)
+            {
+                if($self->route_exists($nation1->name, $nation2->name))
+                {
+                    $self->create_treaty($nation1->name, $nation2->name, 'commercial');
+                    $self->broadcast_event("COMMERCIAL TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name, $nation1->name, $nation2->name);
+                }
+                else
+                {
+                    $self->broadcast_event("COMMERCIAL TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name . " MADE USELESS BY ROUTE CANCELATION", $nation1->name, $nation2->name);
+                }
+            }
+        }
+        elsif($type eq 'NAG')
+        {
+            if(! $present_treaty)
+            {
+                $self->create_treaty($nation1->name, $nation2->name, 'no aggression');
+                $self->broadcast_event("NO AGGRESSION TREATY BETWEEN " . $nation1->name . " AND " . $nation2->name, $nation1->name, $nation2->name);
+            }
+        }
+        else
+        {
+            if($present_treaty && $present_treaty->type ne 'alliance')
+            {
+                $self->create_treaty($nation1->name, $nation2->name, 'alliance');
+                $self->broadcast_event("ALLIANCE BETWEEN " . $nation1->name . " AND " . $nation2->name, $nation1->name, $nation2->name);
+            }
+        }
+    }
+
+
+}
+
+
+
+# TRATIES END ##############################################################
+
 sub register_global_data
 {
     my $self = shift;
